import os
from collections import defaultdict
import pathlib
import dominate
from dominate.tags import *
from human_readable import file_size


directorygen = lambda: defaultdict(directorygen, {".": []})

directory = directorygen()

for root, dirs, files in os.walk("."):
    dirs[:] = [d for d in dirs if d not in [".git"]]
    working = directory
    for part in pathlib.Path(root).parts:
        working = working[part]
    working["."] = [(d, os.path.getsize(os.path.join(root, d))) for d in files if d not in ["index.html", "404.html"]]

def generateindexfragment(path, directory):
    for newdir in directory:
        if newdir == ".":
            continue
        if ".hiddenfolder" in directory[newdir]["."]:
            continue
        with details():
            summary().add(a("/" + newdir, href=path + "/" + newdir))
            generateindexfragment(path + "/" + newdir, directory[newdir])
        
    if directory["."]:
        for file in directory["."]:
            if file[0] == ".hiddenfolder":
                p("This folder is hidden.")
            else:
                p(a("/" + file[0], href=path + "/" + file[0]), f" [{file_size(file[1], binary=True)}]")

    else:
        p("Folder contains no files.")

def generateindex(path, directory, root=False):
    doc = dominate.document(title=path)

    with doc.head:
        link(rel='stylesheet', href='/style.css')

    with doc:
        h1(path)
        path = "."
        if not root:
            p(a("/..", href="./.."))
        generateindexfragment(path, directory)

    return doc


def walk(node, path="."):
    for key, item in node.items():
        if type(item) is defaultdict:
            yield from walk(item, path + "/" + key)
    yield((path, node))

for result in walk(directory, ""):
    if not os.path.exists((result[0] + "/index.html")[1:]):
        with open((result[0] + "/index.html")[1:], "w") as f:
            f.write(generateindex("misc.tantusar.au" + result[0], result[1], root=False if result[0] else True).render())